@@ -41,7 +41,10 @@ if __name__ == '__main__':
 	gmDateTime.init()
 
 from Gnumed.pycommon import gmExceptions, gmPG2, gmDispatcher, gmI18N, gmCfg, gmTools, gmDateTime
-from Gnumed.business import gmAllergy, gmEMRStructItems, gmClinNarrative, gmPathLab
+from Gnumed.business import gmAllergy
+from Gnumed.business import gmPathLab
+from Gnumed.business import gmClinNarrative
+from Gnumed.business import gmEMRStructItems
 from Gnumed.business import gmMedication, gmVaccination
 
 
@@ -230,16 +233,27 @@ SELECT fk_encounter from
 
 		return stays
 	#--------------------------------------------------------
-	# Narrative API
+	def add_hospital_stay(self, episode=None):
+		return gmEMRStructItems.create_hospital_stay (
+			encounter = self.current_encounter['pk_encounter'],
+			episode = episode
+		)
 	#--------------------------------------------------------
-	def add_notes(self, notes=None, episode=None):
+	# API: narrative
+	#--------------------------------------------------------
+	def add_notes(self, notes=None, episode=None, encounter=None):
+
+		enc = gmTools.coalesce (
+			encounter,
+			self.current_encounter['pk_encounter']
+		)
 
 		for note in notes:
 			success, data = gmClinNarrative.create_clin_narrative (
 				narrative = note[1],
 				soap_cat = note[0],
 				episode_id = episode,
-				encounter_id = self.current_encounter['pk_encounter']
+				encounter_id = enc
 			)
 
 		return True
@@ -282,7 +296,7 @@ SELECT fk_encounter from
 			order by date, soap_rank
 		"""
 
-		#xxxxxxxxxxxxxxxx
+		##########################
 		# support row_version in narrative for display in tree
 
 		rows, idx = gmPG2.run_ro_queries(queries=[{'cmd': cmd, 'args': [self.pk_patient]}], get_col_idx=True)
@@ -313,6 +327,20 @@ SELECT fk_encounter from
 
 		return filtered_narrative
 	#--------------------------------------------------------
+	def get_as_journal(self, since=None, until=None, encounters=None, episodes=None, issues=None, soap_cats=None, providers=None, order_by=None, time_range=None):
+		return gmClinNarrative.get_as_journal (
+			patient = self.pk_patient,
+			since = since,
+			until = until,
+			encounters = encounters,
+			episodes = episodes,
+			issues = issues,
+			soap_cats = soap_cats,
+			providers = providers,
+			order_by = order_by,
+			time_range = time_range
+		)
+	#--------------------------------------------------------
 	def search_narrative_simple(self, search_term=''):
 
 		search_term = search_term.strip()
@@ -710,7 +738,7 @@ Procedures: %(procedures)s
 Vaccinations: %(vaccinations)s
 """			) % self.get_statistics()
 	#--------------------------------------------------------
-	def format_summary(self):
+	def format_summary(self, dob=None):
 
 		stats = self.get_statistics()
 		first = self.get_first_encounter()
@@ -738,6 +766,7 @@ Vaccinations: %(vaccinations)s
 		txt += _(' %s documents\n') % stats['documents']
 		txt += _(' %s test results\n') % stats['results']
 		txt += _(' %s hospital stays\n') % stats['stays']
+		# FIXME: perhaps only count "ongoing ones"
 		txt += _(' %s performed procedures\n\n') % stats['procedures']
 
 		txt += _('Allergies and Intolerances\n\n')
@@ -762,11 +791,15 @@ Vaccinations: %(vaccinations)s
 		inds = sorted(vaccs.keys())
 		for ind in inds:
 			ind_count, vacc = vaccs[ind]
-			txt += u' %s (%s%s): %s (%s %s%s%s)\n' % (
+			txt += u' %s (%s%s): %s @ %s (%s %s%s%s)\n' % (
 				ind,
 				gmTools.u_sum,
 				ind_count,
 				vacc['date_given'].strftime('%b %Y').decode(gmI18N.get_encoding()),
+				gmDateTime.format_apparent_age_medically(gmDateTime.calculate_apparent_age (
+					start = dob,
+					end = vacc['date_given']
+				)),
 				vacc['vaccine'],
 				gmTools.u_left_double_angle_quote,
 				vacc['batch_no'],
@@ -1104,48 +1137,13 @@ WHERE
 		return problems
 	#--------------------------------------------------------
 	def problem2episode(self, problem=None):
-		"""
-		Retrieve the cEpisode instance equivalent to the given problem.
-		The problem's type attribute must be 'episode'
-
-		@param problem: The problem to retrieve its related episode for
-		@type problem: A gmEMRStructItems.cProblem instance
-		"""
-		if isinstance(problem, gmEMRStructItems.cProblem) and (problem['type'] == 'episode'):
-			return self.get_episodes(id_list=[problem['pk_episode']])[0]
-
-		if isinstance(problem, gmEMRStructItems.cEpisode):
-			return problem
-
-		raise TypeError('cannot convert [%s] to episode' % problem)
+		return gmEMRStructItems.problem2episode(problem = problem)
 	#--------------------------------------------------------
 	def problem2issue(self, problem=None):
-		"""
-		Retrieve the cIssue instance equivalent to the given problem.
-		The problem's type attribute must be 'issue'.
-
-		@param problem: The problem to retrieve the corresponding issue for
-		@type problem: A gmEMRStructItems.cProblem instance
-		"""
-		if isinstance(problem, gmEMRStructItems.cProblem) and (problem['type'] == 'issue'):
-			return self.get_health_issues(id_list=[problem['pk_health_issue']])[0]
-
-		if isinstance(problem, gmEMRStructItems.cHealthIssue):
-			return problem
-
-		raise TypeError('cannot convert [%s] to health issue' % problem)
+		return gmEMRStructItems.problem2issue(problem = problem)
 	#--------------------------------------------------------
 	def reclass_problem(self, problem):
-		"""Transform given problem into either episode or health issue instance.
-		"""
-		if not isinstance(problem, gmEMRStructItems.cProblem):
-			_log.debug(str(problem))
-			raise TypeError, 'cannot reclass [%s] instance to problem' % type(problem)
-		if problem['type'] == 'episode':
-			return self.get_episodes(id_list=[problem['pk_episode']])[0]
-		if problem['type'] == 'issue':
-			return self.get_health_issues(id_list=[problem['pk_health_issue']])[0]
-		return None
+		return gmEMRStructItems.reclass_problem(problem = problem)
 	#--------------------------------------------------------
 	# health issues API
 	#--------------------------------------------------------
@@ -1216,10 +1214,10 @@ WHERE
 
 		return meds
 	#--------------------------------------------------------
-	def add_substance_intake(self, substance=None, atc=None, episode=None, preparation=None):
+	def add_substance_intake(self, pk_substance=None, pk_component=None, episode=None, preparation=None):
 		return gmMedication.create_substance_intake (
-			substance = substance,
-			atc = atc,
+			pk_substance = pk_substance,
+			pk_component = pk_component,
 			encounter = self.current_encounter['pk_encounter'],
 			episode = episode,
 			preparation = preparation
@@ -1608,7 +1606,7 @@ WHERE
 		)
 		cmd = u"""
 			SELECT pk_encounter
-			from clin.v_most_recent_encounters
+			FROM clin.v_most_recent_encounters
 			WHERE
 				pk_patient = %s
 					and
@@ -1630,6 +1628,10 @@ WHERE
 			False: no "fairly recent" encounter, create new one
 	    	True: success
 		"""
+		if _func_ask_user is None:
+			_log.debug('cannot ask user for guidance, not looking for fairly recent encounter')
+			return False
+
 		cfg_db = gmCfg.cCfgSQL()
 		min_ttl = cfg_db.get2 (
 			option = u'encounter.minimum_ttl',
@@ -1645,11 +1647,11 @@ WHERE
 		)
 		cmd = u"""
 			SELECT pk_encounter
-			from clin.v_most_recent_encounters
+			FROM clin.v_most_recent_encounters
 			WHERE
 				pk_patient=%s
-					and
-				last_affirmed between (now() - %s::interval) and (now() - %s::interval)"""
+					AND
+				last_affirmed BETWEEN (now() - %s::interval) AND (now() - %s::interval)"""
 		enc_rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient, max_ttl, min_ttl]}])
 		# none found
 		if len(enc_rows) == 0:
@@ -1659,7 +1661,7 @@ WHERE
 		# ask user whether to attach or not
 		cmd = u"""
 			SELECT title, firstnames, lastnames, gender, dob
-			from dem.v_basic_person WHERE pk_identity=%s"""
+			FROM dem.v_basic_person WHERE pk_identity=%s"""
 		pats, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient]}])
 		pat = pats[0]
 		pat_str = u'%s %s %s (%s), %s  [#%s]' % (
@@ -1854,8 +1856,8 @@ WHERE
 			cmd = u"""
 SELECT * FROM clin.v_pat_encounters
 WHERE pk_patient = %(pat)s
-order by started desc
-limit 2
+ORDER BY started DESC
+LIMIT 2
 """
 		else:
 			where_parts = []
@@ -1870,19 +1872,19 @@ limit 2
 
 			cmd = u"""
 SELECT *
-from clin.v_pat_encounters
+FROM clin.v_pat_encounters
 WHERE
 	pk_patient = %%(pat)s
-		and
-	pk_encounter in (
+		AND
+	pk_encounter IN (
 		SELECT distinct pk_encounter
-		from clin.v_pat_narrative
+		FROM clin.v_pat_narrative
 		WHERE
 			%s
 	)
-order by started desc
-limit 2
-""" % u' and '.join(where_parts)
+ORDER BY started DESC
+LIMIT 2
+""" % u' AND '.join(where_parts)
 
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = True)
 
@@ -2032,6 +2034,26 @@ order by clin_when desc, pk_episode, unified_name"""
 
 		return tr
 	#------------------------------------------------------------------
+	def get_bmi(self):
+
+		cfg_db = gmCfg.cCfgSQL()
+
+		mass_loincs = cfg_db.get2 (
+			option = u'lab.body_mass_loincs',
+			workplace = _here.active_workplace,
+			bias = u'user',
+			default = []
+		)
+
+		height_loincs = cfg_db.get2 (
+			option = u'lab.body_height_loincs',
+			workplace = _here.active_workplace,
+			bias = u'user',
+			default = []
+		)
+
+		return gmPathLab.calculate_bmi(mass = mass, height = height)	# age = age
+	#------------------------------------------------------------------
 	#------------------------------------------------------------------
 	def get_lab_results(self, limit=None, since=None, until=None, encounters=None, episodes=None, issues=None):
 		"""Retrieves lab result clinical items.
@@ -2224,8 +2246,15 @@ if __name__ == "__main__":
 		emr = cClinicalRecord(aPKey = 12)
 		print emr.is_allergic_to(atcs = tuple(sys.argv[2:]), inns = tuple(sys.argv[2:]), brand = sys.argv[2])
 	#-----------------------------------------
+	def test_get_as_journal():
+		emr = cClinicalRecord(aPKey = 12)
+		for journal_line in emr.get_as_journal():
+			#print journal_line.keys()
+			print u'%(date)s  %(modified_by)s  %(soap_cat)s  %(narrative)s' % journal_line
+			print ""
+	#-----------------------------------------
 	#test_allergy_state()
-	test_is_allergic_to()
+	#test_is_allergic_to()
 
 	#test_get_test_names()
 	#test_get_dates_for_results()
@@ -2238,6 +2267,7 @@ if __name__ == "__main__":
 	#test_get_most_recent_episode()
 	#test_get_almost_recent_encounter()
 	#test_get_meds()
+	test_get_as_journal()
 
 #	emr = cClinicalRecord(aPKey = 12)
 
