@@ -20,6 +20,8 @@ _log = logging.getLogger('gm.docs')
 _log.info(__version__)
 
 MUGSHOT=26
+DOCUMENT_TYPE_VISUAL_PROGRESS_NOTE = u'visual progress note'
+DOCUMENT_TYPE_PRESCRIPTION = u'prescription'
 #============================================================
 class cDocumentFolder:
 	"""Represents a folder with medical documents for a single patient."""
@@ -62,13 +64,39 @@ class cDocumentFolder:
 	#--------------------------------------------------------
 	# API
 	#--------------------------------------------------------
+	def get_latest_freediams_prescription(self):
+		cmd = u"""
+			SELECT pk_doc
+			FROM blobs.v_doc_med
+			WHERE
+				pk_patient = %(pat)s
+					AND
+				type = %(typ)s
+					AND
+				ext_ref = %(ref)s
+			ORDER BY
+				clin_when DESC
+			LIMIT 1
+		"""
+		args = {
+			'pat': self.pk_patient,
+			'typ': DOCUMENT_TYPE_PRESCRIPTION,
+			'ref': u'FreeDiams'
+		}
+		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
+		if len(rows) == 0:
+			_log.info('no FreeDiams prescription available for patient [%s]' % self.pk_patient)
+			return None
+		prescription = cDocument(aPK_obj = rows[0][0])
+		return prescription
+	#--------------------------------------------------------
 	def get_latest_mugshot(self):
 		cmd = u"select pk_obj from blobs.v_latest_mugshot where pk_patient=%s"
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient]}])
 		if len(rows) == 0:
 			_log.info('no mugshots available for patient [%s]' % self.pk_patient)
 			return None
-		mugshot = cMedDocPart(aPK_obj=rows[0][0])
+		mugshot = cDocumentPart(aPK_obj=rows[0][0])
 		return mugshot
 	#--------------------------------------------------------
 	def get_mugshot_list(self, latest_only=True):
@@ -121,6 +149,13 @@ class cDocumentFolder:
 			doc_ids.append(row[0])
 		return doc_ids
 	#--------------------------------------------------------
+	def get_visual_progress_notes(self, episodes=None, encounter=None):
+		return self.get_documents (
+			doc_type = DOCUMENT_TYPE_VISUAL_PROGRESS_NOTE,
+			episodes = episodes,
+			encounter = encounter
+		)
+	#--------------------------------------------------------
 	def get_documents(self, doc_type=None, episodes=None, encounter=None):
 		"""Return list of documents."""
 
@@ -138,7 +173,7 @@ class cDocumentFolder:
 			except (TypeError, ValueError):
 				where_parts.append(u'pk_type = (SELECT pk FROM blobs.doc_type WHERE name = %(type)s)')
 
-		if (episodes is not None) and (len(episodes) != 0):
+		if (episodes is not None) and (len(episodes) > 0):
 			where_parts.append(u'pk_episode IN %(epi)s')
 			args['epi'] = tuple(episodes)
 
@@ -146,17 +181,16 @@ class cDocumentFolder:
 			where_parts.append(u'pk_encounter = %(enc)s')
 
 		cmd = u"%s\nORDER BY clin_when" % (_sql_fetch_document_fields % u' AND '.join(where_parts))
-
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}], get_col_idx = True)
 
-		return [ cMedDoc(row = {'pk_field': 'pk_doc', 'idx': idx, 'data': r}) for r in rows ]
+		return [ cDocument(row = {'pk_field': 'pk_doc', 'idx': idx, 'data': r}) for r in rows ]
 	#--------------------------------------------------------
 	def add_document(self, document_type=None, encounter=None, episode=None):
 		return create_document(document_type = document_type, encounter = encounter, episode = episode)
 #============================================================
 _sql_fetch_document_part_fields = u"select * from blobs.v_obj4doc_no_data where %s"
 
-class cMedDocPart(gmBusinessDBObject.cBusinessDBObject):
+class cDocumentPart(gmBusinessDBObject.cBusinessDBObject):
 	"""Represents one part of a medical document."""
 
 	_cmd_fetch_payload = _sql_fetch_document_part_fields % u"pk_obj = %s"
@@ -236,7 +270,7 @@ order by
 		return rows
 	#--------------------------------------------------------
 	def get_containing_document(self):
-		return cMedDoc(aPK_obj = self._payload[self._idx['pk_doc']])
+		return cDocument(aPK_obj = self._payload[self._idx['pk_doc']])
 	#--------------------------------------------------------
 	# store data
 	#--------------------------------------------------------
@@ -338,7 +372,7 @@ where
 #============================================================
 _sql_fetch_document_fields = u"select * from blobs.v_doc_med where %s"
 
-class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
+class cDocument(gmBusinessDBObject.cBusinessDBObject):
 	"""Represents one medical document."""
 
 	_cmd_fetch_payload = _sql_fetch_document_fields % u"pk_doc = %s"
@@ -346,6 +380,7 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 		u"""update blobs.doc_med set
 				fk_type = %(pk_type)s,
 				fk_episode = %(pk_episode)s,
+				fk_encounter = %(pk_encounter)s,
 				clin_when = %(clin_when)s,
 				comment = gm.nullify_empty_string(%(comment)s),
 				ext_ref = gm.nullify_empty_string(%(ext_ref)s)
@@ -360,14 +395,15 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 		'comment',
 		'clin_when',
 		'ext_ref',
-		'pk_episode'
+		'pk_episode',
+		'pk_encounter'			# mainly useful when moving visual progress notes to their respective encounters
 	]
 	#--------------------------------------------------------
 	def refetch_payload(self, ignore_changes=False):
 		try: del self.__has_unreviewed_parts
 		except AttributeError: pass
 
-		return super(cMedDoc, self).refetch_payload(ignore_changes = ignore_changes)
+		return super(cDocument, self).refetch_payload(ignore_changes = ignore_changes)
 	#--------------------------------------------------------
 	def get_descriptions(self, max_lng=250):
 		"""Get document descriptions.
@@ -401,7 +437,7 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 	def _get_parts(self):
 		cmd = _sql_fetch_document_part_fields % u"pk_doc = %s"
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_obj]}], get_col_idx = True)
-		return [ cMedDocPart(row = {'pk_field': 'pk_obj', 'idx': idx, 'data': r}) for r in rows ]
+		return [ cDocumentPart(row = {'pk_field': 'pk_obj', 'idx': idx, 'data': r}) for r in rows ]
 
 	parts = property(_get_parts, lambda x:x)
 	#--------------------------------------------------------
@@ -426,7 +462,7 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 		)
 		# init document part instance
 		pk_part = rows[0][0]
-		new_part = cMedDocPart(aPK_obj = pk_part)
+		new_part = cDocumentPart(aPK_obj = pk_part)
 		if not new_part.update_data_from_file(fname=file):
 			_log.error('cannot import binary data from [%s] into document part' % file)
 			gmPG2.run_rw_queries (
@@ -442,7 +478,7 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 		new_parts = []
 
 		for filename in files:
-			new_part = self.add_part(file=filename)
+			new_part = self.add_part(file = filename)
 			if new_part is None:
 				msg = 'cannot instantiate document part object'
 				_log.error(msg)
@@ -509,17 +545,27 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 def create_document(document_type=None, encounter=None, episode=None):
 	"""Returns new document instance or raises an exception.
 	"""
-	cmd1 = u"""insert into blobs.doc_med (fk_type, fk_encounter, fk_episode) VALUES (%(type)s, %(enc)s, %(epi)s)"""
-	cmd2 = u"""select currval('blobs.doc_med_pk_seq')"""
-	rows, idx = gmPG2.run_rw_queries (
-		queries = [
-			{'cmd': cmd1, 'args': {'type': document_type, 'enc': encounter, 'epi': episode}},
-			{'cmd': cmd2}
-		],
-		return_data = True
-	)
-	doc_id = rows[0][0]
-	doc = cMedDoc(aPK_obj = doc_id)
+	cmd = u"""INSERT INTO blobs.doc_med (fk_type, fk_encounter, fk_episode) VALUES (%(type)s, %(enc)s, %(epi)s) RETURNING pk"""
+	try:
+		int(document_type)
+	except ValueError:
+		cmd = u"""
+			INSERT INTO blobs.doc_med (
+				fk_type,
+				fk_encounter,
+				fk_episode
+			) VALUES (
+				coalesce (
+					(SELECT pk from blobs.doc_type bdt where bdt.name = %(type)s),
+					(SELECT pk from blobs.doc_type bdt where _(bdt.name) = %(type)s)
+				),
+				%(enc)s,
+				%(epi)s
+			) RETURNING pk"""
+
+	args = {'type': document_type, 'enc': encounter, 'epi': episode}
+	rows, idx = gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}], return_data = True)
+	doc = cDocument(aPK_obj = rows[0][0])
 	return doc
 #------------------------------------------------------------
 def search_for_document(patient_id=None, type_id=None):
@@ -541,7 +587,7 @@ def search_for_document(patient_id=None, type_id=None):
 
 	docs = []
 	for row in rows:
-		docs.append(cMedDoc(row[0]))
+		docs.append(cDocument(row[0]))
 	return docs
 #------------------------------------------------------------
 def delete_document(document_id=None, encounter_id=None):
