@@ -20,7 +20,7 @@ if __name__ == '__main__':
 	sys.path.insert(0, '../../')
 from Gnumed.pycommon import gmTools, gmBorg, gmMatchProvider, gmExceptions, gmDispatcher
 from Gnumed.pycommon import gmPG2, gmBusinessDBObject, gmCfg, gmShellAPI, gmMimeLib, gmLog2
-from Gnumed.business import gmPerson, gmSurgery
+from Gnumed.business import gmPerson, gmSurgery, gmPersonSearch
 
 
 _log = logging.getLogger('gm.forms')
@@ -572,18 +572,18 @@ class cFormEngine(object):
 		"""Generate output suitable for further processing outside this class, e.g. printing."""
 		raise NotImplementedError
 	#--------------------------------------------------------
-	def process (self, data_source=None):
+	def process(self, data_source=None):
 		"""Merge values into the form template.
 		"""
 		pass
 	#--------------------------------------------------------
-	def cleanup (self):
+	def cleanup(self):
 		"""
 		A sop to TeX which can't act as a true filter: to delete temporary files
 		"""
 		pass
 	#--------------------------------------------------------
-	def exe (self, command):
+	def exe(self, command):
 		"""
 		Executes the provided command.
 		If command cotains %F. it is substituted with the filename
@@ -717,7 +717,7 @@ class cLaTeXForm(cFormEngine):
 
 		return gmShellAPI.run_command_in_shell(command = editor_cmd, blocking = True)
 	#--------------------------------------------------------
-	def generate_output(self, instance_file = None, format=None, cleanup=True):
+	def generate_output(self, instance_file = None, format=None):
 
 		if instance_file is None:
 			instance_file = self.instance_filename
@@ -753,7 +753,7 @@ class cLaTeXForm(cFormEngine):
 			else:
 				cmd = r'pdflatex -interaction nonstopmode %s' % sandboxed_instance_filename
 			for run in [1, 2, 3]:
-				if not gmShellAPI.run_command_in_shell(command = cmd, blocking = True):
+				if not gmShellAPI.run_command_in_shell(command = cmd, blocking = True, acceptable_return_codes = [0, 1]):
 					_log.error('problem running pdflatex, cannot generate form output')
 					gmDispatcher.send(signal = 'statustext', msg = _('Error running pdflatex. Cannot turn LaTeX template into PDF.'), beep = True)
 					os.chdir(old_cwd)
@@ -761,30 +761,25 @@ class cLaTeXForm(cFormEngine):
 		finally:
 			os.chdir(old_cwd)
 
-		pdf_name = u'%s.pdf' % os.path.splitext(sandboxed_instance_filename)[0]
-		shutil.move(pdf_name, os.path.split(self.instance_filename)[0])
-		pdf_name = u'%s.pdf' % os.path.splitext(self.instance_filename)[0]
-
-		# cleanup LaTeX sandbox ?
-		if cleanup:
-			for fname in os.listdir(sandbox_dir):
-				os.remove(os.path.join(sandbox_dir, fname))
-			os.rmdir(sandbox_dir)
-
+		sandboxed_pdf_name = u'%s.pdf' % os.path.splitext(sandboxed_instance_filename)[0]
+		target_dir = os.path.split(self.instance_filename)[0]
 		try:
-			open(pdf_name, 'r').close()
-			return pdf_name
+			shutil.move(sandboxed_pdf_name, target_dir)
 		except IOError:
-			_log.exception('cannot open target PDF: %s', pdf_name)
+			_log.exception('cannot move sandboxed PDF: %s -> %s', sandboxed_pdf_name, target_dir)
+			gmDispatcher.send(signal = 'statustext', msg = _('Sandboxed PDF output file cannot be moved.'), beep = True)
+			return None
+
+		final_pdf_name = u'%s.pdf' % os.path.splitext(self.instance_filename)[0]
 
-		gmDispatcher.send(signal = 'statustext', msg = _('PDF output file cannot be opened.'), beep = True)
-		return None
-	#--------------------------------------------------------
-	def cleanup(self):
 		try:
-			os.remove(self.template_filename)
-		except:
-			_log.debug(u'cannot remove template file [%s]', self.template_filename)
+			open(final_pdf_name, 'r').close()
+		except IOError:
+			_log.exception('cannot open target PDF: %s', final_pdf_name)
+			gmDispatcher.send(signal = 'statustext', msg = _('PDF output file cannot be opened.'), beep = True)
+			return None
+
+		return final_pdf_name
 #------------------------------------------------------------
 form_engines[u'L'] = cLaTeXForm
 #============================================================
@@ -835,14 +830,6 @@ class cGnuplotForm(cFormEngine):
 		gp.communicate()
 
 		return
-	#--------------------------------------------------------
-	def cleanup (self):
-		try:
-			os.remove(self.template_filename)
-			os.remove(self.conf_filename)
-			os.remove(self.data_filename)
-		except StandardError:
-			_log.exception(u'cannot remove either of script/conf/data file')
 #------------------------------------------------------------
 form_engines[u'G'] = cGnuplotForm
 #------------------------------------------------------------
@@ -1262,7 +1249,7 @@ if __name__ == '__main__':
 		doc.dispose()		# closes and disposes of the OOo window
 	#--------------------------------------------------------
 	def test_cOOoLetter():
-		pat = gmPerson.ask_for_patient()
+		pat = gmPersonSearch.ask_for_patient()
 		if pat is None:
 			return
 		gmPerson.set_active_patient(patient = pat)
@@ -1289,7 +1276,7 @@ if __name__ == '__main__':
 		template.update_template_from_file(filename = sys.argv[3])
 	#--------------------------------------------------------
 	def test_latex_form():
-		pat = gmPerson.ask_for_patient()
+		pat = gmPersonSearch.ask_for_patient()
 		if pat is None:
 			return
 		gmPerson.set_active_patient(patient = pat)
@@ -1303,7 +1290,7 @@ if __name__ == '__main__':
 		ph = gmMacro.gmPlaceholderHandler()
 		ph.debug = True
 		instance_file = form.substitute_placeholders(data_source = ph)
-		pdf_name = form.generate_output(instance_file = instance_file, cleanup = False)
+		pdf_name = form.generate_output(instance_file = instance_file)
 		print "final PDF file is:", pdf_name
 
 	#--------------------------------------------------------
