@@ -5,7 +5,7 @@ __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
 
-import types, sys, logging, codecs
+import types, sys, logging, codecs, decimal
 
 
 if __name__ == '__main__':
@@ -172,7 +172,7 @@ def get_measurement_types(order_by=None):
 def find_measurement_type(lab=None, abbrev=None, name=None):
 
 		if (abbrev is None) and (name is None):
-			raise ArgumentError('must have <abbrev> and/or <name> set')
+			raise ValueError('must have <abbrev> and/or <name> set')
 
 		where_snippets = []
 
@@ -322,7 +322,8 @@ class cTestResult(gmBusinessDBObject.cBusinessDBObject):
 				fk_intended_reviewer = %(pk_intended_reviewer)s,
 				fk_encounter = %(pk_encounter)s,
 				fk_episode = %(pk_episode)s,
-				fk_type = %(pk_test_type)s
+				fk_type = %(pk_test_type)s,
+				fk_request = %(pk_request)s
 			where
 				pk = %(pk_test_result)s and
 				xmin = %(xmin_test_result)s""",
@@ -349,7 +350,8 @@ class cTestResult(gmBusinessDBObject.cBusinessDBObject):
 		'pk_intended_reviewer',
 		'pk_encounter',
 		'pk_episode',
-		'pk_test_type'
+		'pk_test_type',
+		'pk_request'
 	]
 	#--------------------------------------------------------
 	def format(self, with_review=True, with_comments=True, date_format='%Y-%m-%d %H:%M'):
@@ -1232,6 +1234,36 @@ def get_next_request_ID(lab=None, incrementor_func=None):
 			trailer = most_recent[-1:]
 			return '%s%s' % (header, chr(ord(trailer) + 1))
 #============================================================
+def calculate_bmi(mass=None, height=None, age=None):
+	"""Calculate BMI.
+
+	mass: kg
+	height: cm
+	age: not yet used
+
+	returns:
+		(True/False, data)
+		True: data = (bmi, lower_normal, upper_normal)
+		False: data = error message
+	"""
+	converted, mass = gmTools.input2decimal(mass)
+	if not converted:
+		return False, u'mass: cannot convert <%s> to Decimal' % mass
+
+	converted, height = gmTools.input2decimal(height)
+	if not converted:
+		return False, u'height: cannot convert <%s> to Decimal' % height
+
+	approx_surface = (height / decimal.Decimal(100))**2
+	bmi = mass / approx_surface
+
+	print mass, height, '->', approx_surface, '->', bmi
+
+	lower_normal_mass = 20.0 * approx_surface
+	upper_normal_mass = 25.0 * approx_surface
+
+	return True, (bmi, lower_normal_mass, upper_normal_mass)
+#============================================================
 # main - unit testing
 #------------------------------------------------------------
 if __name__ == '__main__':
@@ -1351,7 +1383,15 @@ if __name__ == '__main__':
 		]
 		print format_test_results(results = results)
 	#--------------------------------------------------------
+	def test_calculate_bmi():
+		done, data = calculate_bmi(mass = sys.argv[2], height = sys.argv[3])
+		bmi, low, high = data
 
+		print "BMI:", bmi
+		print "low:", low, "kg"
+		print "hi :", high, "kg"
+
+	#--------------------------------------------------------
 
 	#test_result()
 	#test_create_test_result()
@@ -1364,7 +1404,8 @@ if __name__ == '__main__':
 	#test_pending()
 	#test_meta_test_type()
 	#test_test_type()
-	test_format_test_results()
+	#test_format_test_results()
+	test_calculate_bmi()
 
 #============================================================
 
