@@ -272,7 +272,7 @@ class cMatchProvider_Func(cMatchProvider):
 		"""get_candidates() must return a list of strings."""
 		if get_candidates is None:
 			_log.error('must define function to retrieve match candidates list')
-			raise ArgumentError('must define function to retrieve match candidates list')
+			raise ValueError('must define function to retrieve match candidates list')
 
 		self._get_candidates = get_candidates
 		cMatchProvider.__init__(self)
@@ -362,6 +362,7 @@ class cMatchProvider_SQL2(cMatchProvider):
 		- each string is a query
 		- each string must contain: "... where <column> %(fragment_condition)s ..."
 		- each string can contain in the where clause: "... %(<context_key>)s ..."
+		- each query must return (data, label)
 
 	context definitions to be used in the queries
 	example: {'ctxt_country': {'where_part': 'and country = %(country)s', 'placeholder': 'country'}}
@@ -389,28 +390,36 @@ class cMatchProvider_SQL2(cMatchProvider):
 	#--------------------------------------------------------
 	def getMatchesByPhrase(self, aFragment):
 		"""Return matches for aFragment at start of phrases."""
-		fragment_condition = u"ilike %(fragment)s"
+
+		fragment_condition = u"ILIKE %(fragment)s"
 		self._args['fragment'] = u"%s%%" % aFragment
-		return self.__find_matches(fragment_condition)
+
+		return self._find_matches(fragment_condition)
 	#--------------------------------------------------------
 	def getMatchesByWord(self, aFragment):
 		"""Return matches for aFragment at start of words inside phrases."""
+
 		fragment_condition = u"~* %(fragment)s"
 		aFragment = gmPG2.sanitize_pg_regex(expression = aFragment, escape_all = False)
 		self._args['fragment'] = u"( %s)|(^%s)" % (aFragment, aFragment)
-		return self.__find_matches(fragment_condition)
+
+		return self._find_matches(fragment_condition)
 	#--------------------------------------------------------
 	def getMatchesBySubstr(self, aFragment):
 		"""Return matches for aFragment as a true substring."""
-		fragment_condition = u"ilike %(fragment)s"
+
+		fragment_condition = u"ILIKE %(fragment)s"
 		self._args['fragment'] = u"%%%s%%" % aFragment
-		return self.__find_matches(fragment_condition)
+
+		return self._find_matches(fragment_condition)
 	#--------------------------------------------------------
 	def getAllMatches(self):
 		"""Return all items."""
 		return self.getMatchesBySubstr(u'')
 	#--------------------------------------------------------
-	def __find_matches(self, fragment_condition):
+	def _find_matches(self, fragment_condition):
+		if self.print_queries:
+			print "----------------------"
 		matches = []
 		for query in self._queries:
 			where_fragments = {'fragment_condition': fragment_condition}
@@ -422,6 +431,10 @@ class cMatchProvider_SQL2(cMatchProvider):
 					self._args[placeholder] = self._context_vals[placeholder]
 					# we do have a context value for this key, so add the where condition
 					where_fragments[context_key] = where_part
+					if self.print_queries:
+						print "ctxt ph:", placeholder
+						print "ctxt where:", where_part
+						print "ctxt val:", self._context_vals[placeholder]
 				except KeyError:
 					# we don't have a context value for this key, so skip the where condition
 					where_fragments[context_key] = u''
@@ -429,10 +442,10 @@ class cMatchProvider_SQL2(cMatchProvider):
 			cmd = query % where_fragments
 
 			if self.print_queries:
-				print self.__class__.__name__
-				print self._context_vals
-				print self._args
-				print cmd
+				print "class:", self.__class__.__name__
+				print "ctxt:", self._context_vals
+				print "args:", self._args
+				print "query:", cmd
 
 			try:
 				rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': self._args}])
