@@ -1782,7 +1782,7 @@ class cCurrentSubstancesGrid(wx.grid.Grid):
 			u'episode': [
 				_('Episode'),
 				_('Substance'),
-				_('Dose'),
+				_('Strength'),
 				_('Schedule'),
 				_('Started'),
 				_('Duration / Until'),
@@ -1792,7 +1792,7 @@ class cCurrentSubstancesGrid(wx.grid.Grid):
 				_('Brand'),
 				_('Schedule'),
 				_('Substance'),
-				_('Dose'),
+				_('Strength'),
 				_('Started'),
 				_('Duration / Until'),
 				_('Episode')
