@@ -157,6 +157,8 @@ class cPhraseWheelListCtrl(wx.ListCtrl, listmixins.ListCtrlAutoWidthMixin):
 #much slower and usually unecesary.  There are many other examples but trust
 #me one needs both
 #-----
+
+# FIXME: support selection-only-or-empty
 class cPhraseWheel(wx.TextCtrl):
 	"""Widget for smart guessing of user fields, after Richard Terry's interface.
 
@@ -204,7 +206,7 @@ class cPhraseWheel(wx.TextCtrl):
 		down pick list is shown
 	@type picklist_delay: integer (milliseconds)
 	"""
-	def __init__ (self, parent=None, id=-1, value='', *args, **kwargs):
+	def __init__ (self, parent=None, id=-1, *args, **kwargs):
 
 		# behaviour
 		self.matcher = None
@@ -228,7 +230,9 @@ class cPhraseWheel(wx.TextCtrl):
 		self.input2match = ''
 		self.left_part = ''
 		self.right_part = ''
-		self.data = None
+		self.__static_tt = None
+		self.__static_tt_extra = None
+		self.__data = None
 
 		self._on_selection_callbacks = []
 		self._on_lose_focus_callbacks = []
@@ -333,7 +337,7 @@ class cPhraseWheel(wx.TextCtrl):
 	def GetData(self, can_create=False, as_instance=False):
 		"""Retrieve the data associated with the displayed string.
 
-			_create_data() must set self.data if possible
+			_create_data() must set self.data if possible (successful)
 		"""
 		if self.data is None:
 			if can_create:
@@ -410,7 +414,7 @@ class cPhraseWheel(wx.TextCtrl):
 		elif valid is False:
 			self.SetBackgroundColour(color_prw_invalid)
 		else:
-			raise ArgumentError(u'<valid> must be True or False')
+			raise ValueError(u'<valid> must be True or False')
 		self.Refresh()
 	#--------------------------------------------------------
 	# internal API
@@ -674,12 +678,67 @@ class cPhraseWheel(wx.TextCtrl):
 	def _create_data(self):
 		raise NotImplementedError('[%s]: cannot create data object' % self.__class__.__name__)
 	#--------------------------------------------------------
+	def _get_data_tooltip(self):
+		# by default do not support dynamic tooltip parts
+		return None
+	#--------------------------------------------------------
+	def __reset_tooltip(self):
+		"""Calculate dynamic tooltip part based on data item.
+
+		- called via ._set_data() each time property .data (-> .__data) is set
+		- hence also called the first time data is set
+		- the static tooltip can be set any number of ways before that
+		- only when data is first set does the dynamic part become relevant
+		- hence it is sufficient to remember the static part when .data is
+		  set for the first time
+		"""
+		if self.__static_tt is None:
+			if self.ToolTip is None:
+				self.__static_tt = u''
+			else:
+				self.__static_tt = self.ToolTip.Tip
+
+		dynamic_part = self._get_data_tooltip()
+		if dynamic_part is None:
+			return
+
+		static_part = self.__static_tt
+		if (self.__static_tt_extra) is not None and (self.__static_tt_extra.strip() != u''):
+			static_part = u'%s\n\n%s' % (
+				static_part,
+				self.__static_tt_extra
+			)
+
+		if static_part == u'':
+			tt = dynamic_part
+		else:
+			if dynamic_part.strip() == u'':
+				tt = static_part
+			else:
+				tt = u'%s\n\n%s\n\n%s' % (
+					dynamic_part,
+					gmTools.u_box_horiz_single * 32,
+					static_part
+				)
+		self.SetToolTipString(tt)
+	#--------------------------------------------------------
 	def __char_is_allowed(self, char=None):
 		# if undefined accept all chars
 		if self.accepted_chars is None:
 			return True
 		return (self.__accepted_chars.match(char) is not None)
 	#--------------------------------------------------------
+	# properties
+	#--------------------------------------------------------
+	def _get_data(self):
+		return self.__data
+
+	def _set_data(self, data):
+		self.__data = data
+		self.__reset_tooltip()
+
+	data = property(_get_data, _set_data)
+	#--------------------------------------------------------
 	def _set_accepted_chars(self, accepted_chars=None):
 		if accepted_chars is None:
 			self.__accepted_chars = None
@@ -733,6 +792,16 @@ class cPhraseWheel(wx.TextCtrl):
 
 	speller_word_separators = property(_get_speller_word_separators, _set_speller_word_separators)
 	#--------------------------------------------------------
+	def _get_static_tt_extra(self):
+		return self.__static_tt_extra
+
+	def _set_static_tt_extra(self, tt):
+		self.__static_tt_extra = tt
+
+	static_tooltip_extra = property(_get_static_tt_extra, _set_static_tt_extra)
+	#--------------------------------------------------------
+	# timer code
+	#--------------------------------------------------------
 	def __init_timer(self):
 		self.__timer = _cPRWTimer()
 		self.__timer.callback = self._on_timer_fired
