@@ -597,11 +597,13 @@ def edit_vaccination(parent=None, vaccination=None, single_entry=True):
 	ea.data = vaccination
 	ea.mode = gmTools.coalesce(vaccination, 'new', 'edit')
 	dlg = gmEditArea.cGenericEditAreaDlg2(parent = parent, id = -1, edit_area = ea, single_entry = single_entry)
-	dlg.SetTitle(gmTools.coalesce(vaccination, _('Adding new vaccination'), _('Editing vaccination')))
+	dlg.SetTitle(gmTools.coalesce(vaccination, _('Adding new vaccinations'), _('Editing vaccination')))
 	if dlg.ShowModal() == wx.ID_OK:
 		dlg.Destroy()
 		return True
 	dlg.Destroy()
+	if not single_entry:
+		return True
 	return False
 #----------------------------------------------------------------------
 def manage_vaccinations(parent=None):
@@ -629,7 +631,7 @@ def manage_vaccinations(parent=None):
 		return False
 	#------------------------------------------------------------
 	def edit(vaccination=None):
-		return edit_vaccination(parent = parent, vaccination = vaccination, single_entry = True)
+		return edit_vaccination(parent = parent, vaccination = vaccination, single_entry = (vaccination is not None))
 	#------------------------------------------------------------
 	def delete(vaccination=None):
 		gmVaccination.delete_vaccination(vaccination = vaccination['pk_vaccination'])
@@ -737,7 +739,7 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 
 		has_errors = False
 
-		if not self._DP_date_given.is_valid_timestamp(allow_none = False):
+		if not self._PRW_date_given.is_valid_timestamp(allow_empty = False):
 			has_errors = True
 
 		vaccine = self._PRW_vaccine.GetData(as_instance = True)
@@ -818,7 +820,7 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 		else:
 			data['soap_cat'] = u'p'
 
-		data['date_given'] = self._DP_date_given.get_pydt()
+		data['date_given'] = self._PRW_date_given.GetData()
 		data['site'] = self._PRW_site.GetValue().strip()
 		data['pk_provider'] = self._PRW_provider.GetData()
 		data['reaction'] = self._PRW_reaction.GetValue().strip()
@@ -835,7 +837,7 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 		else:
 			self.data['soap_cat'] = u'p'
 
-		self.data['date_given'] = self._DP_date_given.get_pydt()
+		self.data['date_given'] = self._PRW_date_given.GetData()
 		self.data['pk_vaccine'] = self._PRW_vaccine.GetData()
 		self.data['batch_no'] = self._PRW_batch.GetValue().strip()
 		self.data['pk_episode'] = self._PRW_episode.GetData(can_create = True, is_open = False)
@@ -849,8 +851,8 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 		return True
 	#----------------------------------------------------------------
 	def _refresh_as_new(self):
-		self._DP_date_given.SetValue(gmDateTime.pydt_now_here())
-		self._CHBOX_anamnestic.SetValue(True)
+		self._PRW_date_given.SetText(data = gmDateTime.pydt_now_here())
+		self._CHBOX_anamnestic.SetValue(False)
 		self._PRW_vaccine.SetText(value = u'', data = None, suppress_smarts = True)
 
 		self._PNL_indications.clear_all()
@@ -864,10 +866,10 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 		self._BTN_report.Enable(False)
 		self._TCTRL_comment.SetValue(u'')
 
-		self._DP_date_given.SetFocus()
+		self._PRW_date_given.SetFocus()
 	#----------------------------------------------------------------
 	def _refresh_from_existing(self):
-		self._DP_date_given.SetValue(self.data['date_given'])
+		self._PRW_date_given.SetText(data = self.data['date_given'])
 		if self.data['soap_cat'] == u's':
 			self._CHBOX_anamnestic.SetValue(True)
 		else:
@@ -889,11 +891,11 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 			self._BTN_report.Enable(True)
 		self._TCTRL_comment.SetValue(gmTools.coalesce(self.data['comment'], u''))
 
-		self._DP_date_given.SetFocus()
+		self._PRW_date_given.SetFocus()
 	#----------------------------------------------------------------
 	def _refresh_as_new_from_existing(self):
-		self._DP_date_given.SetValue(gmDateTime.pydt_now_here())
-		self._CHBOX_anamnestic.SetValue(True)
+		self._PRW_date_given.SetText(data = self.data['date_given'])
+		#self._CHBOX_anamnestic.SetValue(False)
 		self._PRW_vaccine.SetText(value = self.data['vaccine'], data = self.data['pk_vaccine'])
 
 		self._PNL_indications.clear_all()
@@ -910,7 +912,7 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 		self._BTN_report.Enable(False)
 		self._TCTRL_comment.SetValue(u'')
 
-		self._DP_date_given.SetFocus()
+		self._PRW_date_given.SetFocus()
 	#----------------------------------------------------------------
 	# event handlers
 	#----------------------------------------------------------------
