@@ -61,13 +61,13 @@ if __name__ == "__main__":
 	import wx
 
 	# GNUmed
-	from Gnumed.business import gmPerson
+	from Gnumed.business import gmPersonSearch
 
 	_log.info("starting Notebooked progress notes input plugin...")
 
 	try:
 		# obtain patient
-		patient = gmPerson.ask_for_patient()
+		patient = gmPersonSearch.ask_for_patient()
 		if patient is None:
 			print "None patient. Exiting gracefully..."
 			sys.exit(0)
@@ -93,62 +93,3 @@ if __name__ == "__main__":
 
 	_log.info("closing Notebooked progress notes input plugin...")
 #======================================================================
-# $Log: gmNotebookedProgressNoteInputPlugin.py,v $
-# Revision 1.18  2010-02-07 15:19:16  ncq
-# - no more showing in EMR menu
-#
-# Revision 1.17  2009/06/04 16:31:24  ncq
-# - use set-active-patient from pat-search-widgets
-#
-# Revision 1.16  2008/07/10 08:45:14  ncq
-# - fix spelling
-#
-# Revision 1.15  2008/06/24 14:01:02  ncq
-# - improved menu item label
-#
-# Revision 1.14  2008/03/06 18:32:31  ncq
-# - standard lib logging only
-#
-# Revision 1.13  2008/01/27 21:21:59  ncq
-# - no more gmCfg
-#
-# Revision 1.12  2006/12/18 12:12:27  ncq
-# - fix test suite
-#
-# Revision 1.11  2006/11/05 16:05:35  ncq
-# - cleanup, tabify
-#
-# Revision 1.10  2006/10/31 16:06:19  ncq
-# - no more gmPG
-#
-# Revision 1.9	2006/10/25 07:23:30  ncq
-# - no gmPG no more
-#
-# Revision 1.8	2006/05/04 09:49:20  ncq
-# - get_clinical_record() -> get_emr()
-# - adjust to changes in set_active_patient()
-# - need explicit set_active_patient() after ask_for_patient() if wanted
-#
-# Revision 1.7	2005/10/03 13:59:59  sjtan
-# indentation errors
-#
-# Revision 1.6	2005/09/26 18:01:52  ncq
-# - use proper way to import wx26 vs wx2.4
-# - note: THIS WILL BREAK RUNNING THE CLIENT IN SOME PLACES
-# - time for fixup
-#
-# Revision 1.5	2005/09/12 15:11:15  ncq
-# - tab name capitalized
-#
-# Revision 1.4	2005/06/30 10:21:01  cfmoro
-# String corrections
-#
-# Revision 1.3	2005/06/07 10:19:18  ncq
-# - string improvement
-#
-# Revision 1.2	2005/05/12 15:13:28  ncq
-# - cleanup
-#
-# Revision 1.1	2005/05/08 21:45:25  ncq
-# - new plugin for progress note input ...
-#
